@@ -232,7 +232,7 @@ if (ICLUST.options$beta.size < min(size1,size2)) {
 
 if(test.beta & test.alpha) { break} else { #we have failed the combining criteria 
 
-            if((ICLUST.options$n.clus > 0) & ((num.var - count -1 ) <= ICLUST.options$n.clus) ) {warning ("Clusters formed as requested do not meet the alpha and beta criteria. Perhaps you should rethink the number of cluster settings.")
+            if((ICLUST.options$n.clus > 0) & ((num.var - count ) >= ICLUST.options$n.clus) ) {warning ("Clusters formed as requested do not meet the alpha and beta criteria. Perhaps you should rethink the number of cluster settings.")
 			                break } else {   
 			if (beta.combined < ICLUST.options$beta.min) {
 			
