@@ -116,7 +116,9 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
                        Structure <- loadings %*% Phi} else {Structure <- loadings
                        }
     
-    if(scores) {result$scores <- factor.scores(scale(x.matrix),Structure) }
+    if(scores) {result$scores <- factor.scores(scale(x.matrix),Structure)
+                result$weigths<- result$scores$weights
+                result$scores <- result$scores$scores}
     return(result)
    }
   
