@@ -179,6 +179,8 @@ print(object$total,digits=digits)
            print(round(object$R2,digits))
              cat("\nCohen's set correlation R2 \n") 
            print(round(object$Rset,digits))
+           cat("\nSquared Canonical Correlations\n")
+           print(round(object$cancor,digits))
            
            }
            
